==> huaweicloudsdkworkspaceapp-3.1.118-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/create_policy_template_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreatePolicyTemplateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'policy_group': 'PolicyTemplate'
    }

    attribute_map = {
        'policy_group': 'policy_group'
    }

    def __init__(self, policy_group=None):
        """CreatePolicyTemplateReq

        The model defined in huaweicloud sdk

        :param policy_group: 
        :type policy_group: :class:`huaweicloudsdkworkspaceapp.v1.PolicyTemplate`
        """
        
        

        self._policy_group = None
        self.discriminator = None

        self.policy_group = policy_group

    @property
    def policy_group(self):
        """Gets the policy_group of this CreatePolicyTemplateReq.

        :return: The policy_group of this CreatePolicyTemplateReq.
        :rtype: :class:`huaweicloudsdkworkspaceapp.v1.PolicyTemplate`
        """
        return self._policy_group

    @policy_group.setter
    def policy_group(self, policy_group):
        """Sets the policy_group of this CreatePolicyTemplateReq.

        :param policy_group: The policy_group of this CreatePolicyTemplateReq.
        :type policy_group: :class:`huaweicloudsdkworkspaceapp.v1.PolicyTemplate`
        """
        self._policy_group = policy_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePolicyTemplateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.145-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/create_policy_template_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreatePolicyTemplateReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'policy_group': 'PolicyTemplate'
    }

    attribute_map = {
        'policy_group': 'policy_group'
    }

    def __init__(self, policy_group=None):
        r"""CreatePolicyTemplateReq

        The model defined in huaweicloud sdk

        :param policy_group: 
        :type policy_group: :class:`huaweicloudsdkworkspaceapp.v1.PolicyTemplate`
        """
        
        

        self._policy_group = None
        self.discriminator = None

        self.policy_group = policy_group

    @property
    def policy_group(self):
        r"""Gets the policy_group of this CreatePolicyTemplateReq.

        :return: The policy_group of this CreatePolicyTemplateReq.
        :rtype: :class:`huaweicloudsdkworkspaceapp.v1.PolicyTemplate`
        """
        return self._policy_group

    @policy_group.setter
    def policy_group(self, policy_group):
        r"""Sets the policy_group of this CreatePolicyTemplateReq.

        :param policy_group: The policy_group of this CreatePolicyTemplateReq.
        :type policy_group: :class:`huaweicloudsdkworkspaceapp.v1.PolicyTemplate`
        """
        self._policy_group = policy_group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePolicyTemplateReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
